API
===

Auto-generated summary of CloudDrift's API. For more details and examples, refer to the different Jupyter Notebooks.

.. currentmodule:: clouddrift

.. autosummary::
    :toctree: _autosummary
    :template: module.rst
    :recursive:
    
    adapters.gdp
    adapters.gdp1h
    adapters.gdp6h
    adapters.glad
    adapters.mosaic
    adapters.subsurface_floats
    datasets
    kinematics
    pairs
    plotting
    ragged
    raggedarray
    signal
    sphere
    wavelet
